CompareRecipe: Generating comparison values
===========================================

The CompareRecipe extension lets you generate different Recipes
againt the same table to generate comparison values.


.. module:: recipe

.. autoclass:: CompareRecipe
    :members: compare
    :noindex:    